==> 0.3.1.tar.gz: lib/hash_generator.dart <==
library hash_generator;

import 'dart:math';

/// O Gerador do hash.
class HashGenerator {
  static int _maxValue = 500;
  static List<String> _caracteres = [""];

  /// Retorna o Código hash
  static String generate(
      {int lenght,
      bool withLetter,
      bool withNumber,
      bool withSymbol,
      String startWith}) {

    String resultado = "";

    if (lenght == null) {
      lenght = 16;
    }
    if (withLetter == null) {
      withLetter = true;
    }
    if (withNumber == null) {
      withNumber = true;
    }
    if (withSymbol == null) {
      withSymbol = true;
    }
    if (startWith == null) {
      startWith = null;
    }

    if (lenght > _maxValue) {
      throw ("Valor máximo é $_maxValue");
    }
    if (withLetter) {
      _caracteres.addAll(_letras());
    }
    if (withNumber) {
      _caracteres.addAll(_numeros());
    }
    if (withSymbol) {
      _caracteres.addAll(_simbolos());
    }

    if(startWith.length > lenght){
      throw("A quantidade de caracteres no StartWith deve ser menor que o Lenght total.");
    }

    for (int i = 0; i < lenght - startWith.length; i++) {
      resultado += _caracteres.elementAt(Random().nextInt(_caracteres.length));
    }

    return startWith.toString()+resultado;
  }

  static List<String> _letras() {
    List<String> letras = [
      'a',
      'b',
      'c',
      'd',
      'e',
      'f',
      'g',
      'h',
      'i',
      'j',
      'l',
      'm',
      'n',
      'o',
      'p',
      'q',
      'r',
      's',
      't',
      'u',
      'v',
      'x',
      'z',
      'k',
      'w',
      'y',
      'A',
      'B',
      'C',
      'D',
      'E',
      'F',
      'G',
      'H',
      'I',
      'J',
      'L',
      'M',
      'N',
      'O',
      'P',
      'Q',
      'R',
      'S',
      'T',
      'U',
      'V',
      'X',
      'Z',
      'K',
      'W',
      'Y',
    ];
    return letras;
  }

  static List<String> _numeros() {
    List<String> numeros = [
      '0',
      '1',
      '2',
      '3',
      '4',
      '5',
      '6',
      '7',
      '8',
      '9',
    ];
    return numeros;
  }

  static List<String> _simbolos() {
    List<String> simbolos = [
      '!',
      '@',
      '#',
      '^',
      '%',
      '&',
      '*',
      '-',
      '_',
      '+',
    ];
    return simbolos;
  }
}

==> 0.4.1.tar.gz: lib/hash_generator.dart <==
library hash_generator;

import 'dart:math';

/// O Gerador do hash.
class HashGenerator {
  static int _maxValue = 500;
  static List<String> _caracteres = [""];

  /// Retorna o Código hash
  static String generate(
      {int lenght,
      bool withLetter,
      bool withNumber,
      bool withSymbol,
      String startWith,
      String endWith}) {
    String resultado = "";

    if (lenght == null) {
      lenght = 16;
    }
    if (withLetter == null) {
      withLetter = true;
    }
    if (withNumber == null) {
      withNumber = true;
    }
    if (withSymbol == null) {
      withSymbol = true;
    }
    if (startWith == null) {
      startWith = "";
    }
    if (endWith == null) {
      endWith = "";
    }

    if (lenght > _maxValue) {
      throw ("Valor máximo é $_maxValue");
    }
    if (withLetter) {
      _caracteres.addAll(_letras());
    }
    if (withNumber) {
      _caracteres.addAll(_numeros());
    }
    if (withSymbol) {
      _caracteres.addAll(_simbolos());
    }

    if (startWith.length > lenght) {
      throw ("A quantidade de caracteres no StartWith deve ser menor que o Lenght total.");
    }
    if (endWith.length > lenght) {
      throw ("A quantidade de caracteres no EndWith deve ser menor que o Lenght total.");
    }
    if ((startWith.length + endWith.length) > lenght) {
      throw ("A quantidade de caracteres somados no StartWith e no EndWith devem ser menor que o Lenght total.");
    }

    for (int i = 0; i < lenght - (startWith.length + endWith.length); i++) {
      resultado += _caracteres.elementAt(Random().nextInt(_caracteres.length));
    }

    return startWith.toString() + resultado + endWith.toString();
  }

  static List<String> _letras() {
    List<String> letras = [
      'a',
      'b',
      'c',
      'd',
      'e',
      'f',
      'g',
      'h',
      'i',
      'j',
      'l',
      'm',
      'n',
      'o',
      'p',
      'q',
      'r',
      's',
      't',
      'u',
      'v',
      'x',
      'z',
      'k',
      'w',
      'y',
      'A',
      'B',
      'C',
      'D',
      'E',
      'F',
      'G',
      'H',
      'I',
      'J',
      'L',
      'M',
      'N',
      'O',
      'P',
      'Q',
      'R',
      'S',
      'T',
      'U',
      'V',
      'X',
      'Z',
      'K',
      'W',
      'Y',
    ];
    return letras;
  }

  static List<String> _numeros() {
    List<String> numeros = [
      '0',
      '1',
      '2',
      '3',
      '4',
      '5',
      '6',
      '7',
      '8',
      '9',
    ];
    return numeros;
  }

  static List<String> _simbolos() {
    List<String> simbolos = [
      '!',
      '@',
      '#',
      '^',
      '%',
      '&',
      '*',
      '-',
      '_',
      '+',
    ];
    return simbolos;
  }
}
